@@ -25,13 +25,20 @@ hdr_algorithm["Ls"] = "Luminance sharpness"
 
 tm_preset = OrderedDict()
 tm_preset["Nb"] = "Natural balanced"
+tm_preset["Ns"] = "Natural sharp"
 tm_preset["Nbl"] = "Natural back light"
-tm_preset["Npc"] = "Natural powerful colours"
+tm_preset["NBbl"] = "Natural Bright back light"
+tm_preset["NDbl"] = "Natural Dark back light"
+tm_preset["Nhd"] = "Natural highlight details"
 tm_preset["Ndb"] = "Natural details brightened"
+tm_preset["Npc"] = "Natural powerful colours"
 tm_preset["Lb"] = "Landscape backlit"
 tm_preset["Ls"] = "Landscape sunset"
 tm_preset["Lpc"] = "Landscape powerful colours"
 tm_preset["Lcad"] = "Landscape colour and detail"
+tm_preset["LB"] = "Landscape Brilliant"
 tm_preset["Afd"] = "Architecture fine detail"
+tm_preset["Abi"] = "Architecture brighten interior"
+tm_preset["Ss"] = "Surreal standard"
 tm_preset["Spc"] = "Surreal powerful colours"
 tm_preset["SE"] = "Surreal Extreme"
